# 🍅 pytest-tomato 

pytest plugin for [tomato-bot](https://tomato-bot/)

## Installation
`pip install pytest-tomato`

## Usage
In order to parse test results the tomato bot read junit xml files.  
pass `--junit-xml=tests.junit.xml` flag to pytest and Tomato will take the lead
